html{font-family:var(--font)!important}.rti--container{max-width:inherit;--rti-tag:var(--primary-color)!important;background-color:var(--secondary-background-color)}body{color:#fff;background-color:inherit!important}h3{color:var(--text-color);background-color:var(--background-color)}button,span{color:#fff}.rti--input{background-color:var(--secondary-background-color)}
/*# sourceMappingURL=main.dd00a657.chunk.css.map */