(this.webpackJsonpstreamlit_tags=this.webpackJsonpstreamlit_tags||[]).push([[0],{15:function(e,t,a){e.exports=a(25)},23:function(e,t,a){},25:function(e,t,a){"use strict";a.r(t);var n=a(1),r=a.n(n),l=a(9),c=a.n(l),u=a(2),i=a(7),o=a(14),s=(a(23),Object(i.b)((function(e){var t=e.args,a=t.label,l=t.text,c=t.initialValue,s=(t.theme,Object(n.useState)(c)),m=Object(u.a)(s,2),b=m[0],f=m[1];return Object(n.useEffect)((function(){return i.a.setFrameHeight()})),r.a.createElement("div",null,r.a.createElement(o.a,{value:b,onChange:function(e){return f(t=e),void i.a.setComponentValue(t);var t},name:a,placeHolder:l}))}))),m=a(12),b=a(13),f=a(30),p=a(26),E=new m.a;c.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(b.a,{value:E},r.a.createElement(f.a,{theme:p.a},r.a.createElement(s,null)))),document.getElementById("root"))}},[[15,1,2]]]);
//# sourceMappingURL=main.d216b0eb.chunk.js.map